@@ -13,7 +13,7 @@ require Exporter;
 our @ISA = 'Exporter';
 our @EXPORT = qw(WILDCARD BOF EOF);
 
-our $VERSION = '0.200'; # VERSION
+our $VERSION = '0.201'; # VERSION
 
 
 has 'sidelen' => (
@@ -53,16 +53,15 @@ sub _detect{
 
 sub _diff{
     my ($a,$b) = @_;
-    my ($org_a,$org_b) = @_;
     my @d = sdiff($a,$b);
     my @rr;
     my $idx = 0;
     for my $r (@d){
         if( $r->[0] eq 'u' ){
-            push(@rr,$org_a->[$idx]);
+            push(@rr,$a->[$idx]);
         }
         else{
-            push(@rr,WILDCARD) unless WILDCARD == @rr[@rr-1];
+            push(@rr,WILDCARD) unless WILDCARD == $rr[-1];
         }
         $idx++ if $r->[0] ne '+';
     }
@@ -85,7 +84,7 @@ Template::Reverse - A template generator getting different parts between pair of
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 SYNOPSIS
 
@@ -185,8 +184,8 @@ It returns like below.
     # qw(A b C) -> (BOF, qw(A b C), EOF)
     # 
     # [ { [BOF, 'A'],['C', EOF] } ] <- Please focus at data, not expression.
-    #   : :........: :...:      :     
-    #   :  pre       post       :
+    #   : :........: :..,,,,,.: :     
+    #   :     pre       post    :
     #   :.......................:  
     #           Part #1
     #
@@ -195,7 +194,7 @@ It returns like below.
     #
     # [ { [BOF, 'A'], ['C'] }, { ['C'], ['E', EOF] } ]
     #   : :........:  :...: :  : :...:  :........: :
-    #   :  pre        post  :  :  pre   post       :
+    #   :  pre        post  :  :  pre      post    :
     #   :...................:  :...................:
     #          Part #1                Part #2
     #
@@ -228,6 +227,14 @@ It returns like below.
 
 Returned arrayRef is list of detected changing parts.
 
+Actually, the returned value is like below.
+
+    [ 
+        {pre=>[BOF, ...], post=>[...]},
+        ...
+        {pre=>[...], post=>[..., EOF]},
+    ]
+
 You can get a changed token if you find just 'pre' and 'post' parts on splited target.
 
 =head1 SEE ALSO
