@@ -21,11 +21,9 @@ sub partition_by{
     foreach my $item (@list){
         if( $funcref->($item) ){
             if($curarr){
-                push(@ret, $curarr,[$item]);
-            }
-            else{
-                push(@ret, [$item]);   
+                push(@ret, $curarr);
             }
+            push(@ret, [$item]);   
             $curarr = [];
         }
         else{
@@ -50,7 +48,7 @@ Template::Reverse::Util
 
 =head1 VERSION
 
-version 0.200
+version 0.201
 
 =head1 AUTHOR
 
